Class: Reeve::Invocation::NullScoper
- Inherits:
-
Object
- Object
- Reeve::Invocation::NullScoper
- Defined in:
- lib/reeve/invocation.rb
Overview
No scoper wired in: a result that cannot be narrowed cannot be returned.
Instance Method Summary collapse
Instance Method Details
#scope(context:, guard:, result:) ⇒ Object
32 33 34 35 36 37 |
# File 'lib/reeve/invocation.rb', line 32 def scope(context:, guard:, result:) ScopeResult.deny( rule: Decision::UNSCOPED_DERIVED_RESULT, detail: "no scoper is configured, so the result could not be narrowed" ) end |